@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025 Huang Feiyu
 
 ;; Author: Huang Feiyu <sibadake1@163.com>
-;; Package-Version: 20251228.316
-;; Package-Revision: de48a1af4661
+;; Package-Version: 20260130.1352
+;; Package-Revision: e66dba299ed3
 ;; Package-Requires: ((emacs "27.1") (posframe "1.4.0") (eglot "1.8"))
 ;; Keywords: tools, languages, convenience, mouse, hover
 ;; URL: https://github.com/huangfeiyu/eldoc-mouse
@@ -172,6 +172,10 @@ this list for specific mode.")
     (setq eldoc--last-request-state nil)
     (eldoc-print-current-symbol-info)))
 
+;; Don't restore the minor mode.
+(with-eval-after-load 'desktop
+  (add-to-list 'desktop-minor-mode-handlers '(eldoc-mouse-mode . ignore)))
+
 (defun eldoc-mouse-enable ()
   "Enable eldoc-mouse in buffers."
   ;; Enable mouse tracking.
